==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>図面を閉じています...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>無題</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <location filename="../NewFile.js" line="+120"/>
        <source>Loading...</source>
        <translation>読込中...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import Error</source>
        <translation>インポートエラー</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cannot open file</source>
        <translation>ファイルを開けません</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>適切なインポーターがみつかりません。ファイルフォーマットと拡張子をチェックしてください。</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>アクセス権、ファイルフォーマット、拡張子をチェックしてください。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File is empty.</source>
        <translation>ファイルは空です。</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Opened drawing:</source>
        <translation>オープンされた図面:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>フォーマット:</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Untitled %1</source>
        <translation>無題%1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>read-only</source>
        <translation>読み込み専用</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>このドキュメントへの変更を保存しますか？&lt;br&gt;&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>保存しなければ変更は失われます。</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;N 新規作成</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>図面を閉じています...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>無題</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <location filename="../NewFile.js" line="+114"/>
        <source>Opening drawing:</source>
        <translation>オープンされた図面:</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="vanished">読込中...</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Import Error</source>
        <translation>インポートエラー</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Cannot open file</source>
        <translation>ファイルを開けません</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>適切なインポーターがみつかりません。ファイルフォーマットと拡張子をチェックしてください。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>アクセス権、ファイルフォーマット、拡張子をチェックしてください。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>File is empty.</source>
        <translation>ファイルは空です。</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Drawing loaded successfully:</source>
        <translation>ロード済み:</translation>
    </message>
    <message>
        <source>Opened drawing:</source>
        <translation type="vanished">オープンされた図面:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Format:</source>
        <translation>フォーマット:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Untitled %1</source>
        <translation>無題%1</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>read-only</source>
        <translation>読み込み専用</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>このドキュメントへの変更を保存しますか？&lt;br&gt;&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>保存しなければ変更は失われます。</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;N 新規作成</translation>
    </message>
</context>
</TS>
